@@ -1,5 +1,8 @@
 from unittest import TestCase
-from plugins.EventdetectionIDT import *
+import yapsy
+from yapsy import IPlugin
+from PerceptionToolkit.plugins.EventdetectionIDT import EventdetectionIDT
+import numpy as np
 
 
 class TestEventdetectionIDT(TestCase):
